summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2014-12-28 17:31:07 +0000
committerCarl Hetherington <cth@carlh.net>2014-12-28 17:31:07 +0000
commitb2c820e178296722eeff355064f0469907465332 (patch)
tree715dd1d472acfbdaee35577b80a3b1794514a7d9
parent1d3602b37934c3d0404e6a2fa9a5d3c5f6b70309 (diff)
Rename test DCP from foo to dcp_test1.
-rwxr-xr-xrun/tests2
-rw-r--r--test/cpl_sar_test.cc2
-rw-r--r--test/dcp_test.cc20
-rw-r--r--test/read_dcp_test.cc2
-rw-r--r--test/ref/DCP/dcp_test1/18be072e-5a0f-44e1-b2eb-c8a52ae12789_pkl.xml (renamed from test/ref/DCP/foo/18be072e-5a0f-44e1-b2eb-c8a52ae12789_pkl.xml)0
-rw-r--r--test/ref/DCP/dcp_test1/81fb54df-e1bf-4647-8788-ea7ba154375b_cpl.xml (renamed from test/ref/DCP/foo/81fb54df-e1bf-4647-8788-ea7ba154375b_cpl.xml)0
-rw-r--r--test/ref/DCP/dcp_test1/ASSETMAP.xml (renamed from test/ref/DCP/foo/ASSETMAP.xml)0
-rw-r--r--test/ref/DCP/dcp_test1/VOLINDEX.xml (renamed from test/ref/DCP/foo/VOLINDEX.xml)0
-rw-r--r--test/ref/DCP/dcp_test1/audio.mxf (renamed from test/ref/DCP/foo/audio.mxf)bin161326 -> 161326 bytes
-rw-r--r--test/ref/DCP/dcp_test1/video.mxf (renamed from test/ref/DCP/foo/video.mxf)bin26080 -> 26080 bytes
10 files changed, 13 insertions, 13 deletions
diff --git a/run/tests b/run/tests
index a9b57ad8..e1beb731 100755
--- a/run/tests
+++ b/run/tests
@@ -31,7 +31,7 @@ if [ "$?" != "0" ]; then
fi
# Check the first DCP written by the unit tests
-diff -ur test/ref/DCP/foo $work/DCP/foo
+diff -ur test/ref/DCP/dcp_test1 $work/DCP/dcp_test1
if [ "$?" != "0" ]; then
echo "FAIL: files differ"
exit 1
diff --git a/test/cpl_sar_test.cc b/test/cpl_sar_test.cc
index 59a91c84..bce57f58 100644
--- a/test/cpl_sar_test.cc
+++ b/test/cpl_sar_test.cc
@@ -32,7 +32,7 @@ BOOST_AUTO_TEST_CASE (cpl_sar)
{
shared_ptr<dcp::ReelMonoPictureAsset> pa (
new dcp::ReelMonoPictureAsset (
- shared_ptr<dcp::MonoPictureMXF> (new dcp::MonoPictureMXF ("test/ref/DCP/foo/video.mxf")),
+ shared_ptr<dcp::MonoPictureMXF> (new dcp::MonoPictureMXF ("test/ref/DCP/dcp_test1/video.mxf")),
0
)
);
diff --git a/test/read_dcp_test.cc b/test/read_dcp_test.cc
index a17b0a01..6aed62a4 100644
--- a/test/read_dcp_test.cc
+++ b/test/read_dcp_test.cc
@@ -27,7 +27,7 @@ using boost::shared_ptr;
/* Read DCP that is in git and make sure that basic stuff is read in correctly */
BOOST_AUTO_TEST_CASE (read_dcp)
{
- dcp::DCP d ("test/ref/DCP/foo");
+ dcp::DCP d ("test/ref/DCP/dcp_test1");
d.read ();
list<shared_ptr<dcp::CPL> > cpls = d.cpls ();
diff --git a/test/ref/DCP/foo/18be072e-5a0f-44e1-b2eb-c8a52ae12789_pkl.xml b/test/ref/DCP/dcp_test1/18be072e-5a0f-44e1-b2eb-c8a52ae12789_pkl.xml
index 3e64ae8f..3e64ae8f 100644
--- a/test/ref/DCP/foo/18be072e-5a0f-44e1-b2eb-c8a52ae12789_pkl.xml
+++ b/test/ref/DCP/dcp_test1/18be072e-5a0f-44e1-b2eb-c8a52ae12789_pkl.xml
diff --git a/test/ref/DCP/foo/81fb54df-e1bf-4647-8788-ea7ba154375b_cpl.xml b/test/ref/DCP/dcp_test1/81fb54df-e1bf-4647-8788-ea7ba154375b_cpl.xml
index 2fc53fb1..2fc53fb1 100644
--- a/test/ref/DCP/foo/81fb54df-e1bf-4647-8788-ea7ba154375b_cpl.xml
+++ b/test/ref/DCP/dcp_test1/81fb54df-e1bf-4647-8788-ea7ba154375b_cpl.xml
diff --git a/test/ref/DCP/foo/ASSETMAP.xml b/test/ref/DCP/dcp_test1/ASSETMAP.xml
index 58e60c29..58e60c29 100644
--- a/test/ref/DCP/foo/ASSETMAP.xml
+++ b/test/ref/DCP/dcp_test1/ASSETMAP.xml
diff --git a/test/ref/DCP/foo/VOLINDEX.xml b/test/ref/DCP/dcp_test1/VOLINDEX.xml
index 021685e9..021685e9 100644
--- a/test/ref/DCP/foo/VOLINDEX.xml
+++ b/test/ref/DCP/dcp_test1/VOLINDEX.xml
diff --git a/test/ref/DCP/foo/audio.mxf b/test/ref/DCP/dcp_test1/audio.mxf
index 0d6ab6b1..0d6ab6b1 100644
--- a/test/ref/DCP/foo/audio.mxf
+++ b/test/ref/DCP/dcp_test1/audio.mxf
Binary files differ
diff --git a/test/ref/DCP/foo/video.mxf b/test/ref/DCP/dcp_test1/video.mxf
index dc0afeab..dc0afeab 100644
--- a/test/ref/DCP/foo/video.mxf
+++ b/test/ref/DCP/dcp_test1/video.mxf
Binary files differ
diff --git a/test/dcp_test.cc b/test/dcp_test.cc
index b4ffc1d1..67593187 100644
--- a/test/dcp_test.cc
+++ b/test/dcp_test.cc
@@ -37,7 +37,7 @@
using std::string;
using boost::shared_ptr;
-/** Test creation of a DCP from very simple inputs */
+/** Test creation of a 2D DCP from very simple inputs */
BOOST_AUTO_TEST_CASE (dcp_test1)
{
Kumu::libdcp_test = true;
@@ -52,10 +52,10 @@ BOOST_AUTO_TEST_CASE (dcp_test1)
mxf_meta.product_name = "OpenDCP";
mxf_meta.product_version = "0.0.25";
- /* We're making build/test/foo */
- boost::filesystem::remove_all ("build/test/DCP/foo");
- boost::filesystem::create_directories ("build/test/DCP/foo");
- dcp::DCP d ("build/test/DCP/foo");
+ /* We're making build/test/DCP/dcp_test1 */
+ boost::filesystem::remove_all ("build/test/DCP/dcp_test1");
+ boost::filesystem::create_directories ("build/test/DCP/dcp_test1");
+ dcp::DCP d ("build/test/DCP/dcp_test1");
shared_ptr<dcp::CPL> cpl (new dcp::CPL ("A Test DCP", dcp::FEATURE));
cpl->set_content_version_id ("urn:uri:81fb54df-e1bf-4647-8788-ea7ba154375b_2012-07-17T04:45:18+00:00");
cpl->set_content_version_label_text ("81fb54df-e1bf-4647-8788-ea7ba154375b_2012-07-17T04:45:18+00:00");
@@ -63,7 +63,7 @@ BOOST_AUTO_TEST_CASE (dcp_test1)
shared_ptr<dcp::MonoPictureMXF> mp (new dcp::MonoPictureMXF (dcp::Fraction (24, 1)));
mp->set_metadata (mxf_meta);
- shared_ptr<dcp::PictureMXFWriter> picture_writer = mp->start_write ("build/test/DCP/foo/video.mxf", dcp::SMPTE, false);
+ shared_ptr<dcp::PictureMXFWriter> picture_writer = mp->start_write ("build/test/DCP/dcp_test1/video.mxf", dcp::SMPTE, false);
dcp::File j2c ("test/data/32x32_red_square.j2c");
for (int i = 0; i < 24; ++i) {
picture_writer->write (j2c.data (), j2c.size ());
@@ -72,7 +72,7 @@ BOOST_AUTO_TEST_CASE (dcp_test1)
shared_ptr<dcp::SoundMXF> ms (new dcp::SoundMXF (dcp::Fraction (24, 1), 48000, 1));
ms->set_metadata (mxf_meta);
- shared_ptr<dcp::SoundMXFWriter> sound_writer = ms->start_write ("build/test/DCP/foo/audio.mxf", dcp::SMPTE);
+ shared_ptr<dcp::SoundMXFWriter> sound_writer = ms->start_write ("build/test/DCP/dcp_test1/audio.mxf", dcp::SMPTE);
SF_INFO info;
info.format = 0;
@@ -105,7 +105,7 @@ BOOST_AUTO_TEST_CASE (dcp_test1)
d.write_xml (dcp::SMPTE, xml_meta);
/* build/test/DCP/foo is checked against test/ref/DCP/foo by run-tests.sh */
}
static void
@@ -117,9 +117,9 @@ note (dcp::NoteType, string s)
/** Test comparison of a DCP with itself */
BOOST_AUTO_TEST_CASE (dcp_test2)
{
- dcp::DCP A ("test/ref/DCP/foo");
+ dcp::DCP A ("test/ref/DCP/dcp_test1");
A.read ();
- dcp::DCP B ("test/ref/DCP/foo");
+ dcp::DCP B ("test/ref/DCP/dcp_test1");
B.read ();
BOOST_CHECK (A.equals (B, dcp::EqualityOptions(), boost::bind (&note, _1, _2)));
@@ -105,7 +105,7 @@ BOOST_AUTO_TEST_CASE (dcp_test1)
d.write_xml (dcp::SMPTE, xml_meta);
- /* build/test/DCP/foo is checked against test/ref/DCP/foo by run-tests.sh */
+ /* build/test/DCP/dcp_test1 is checked against test/ref/DCP/dcp_test1 by run-tests.sh */
}
static void